@@ -478,19 +478,9 @@ cheese_webcam_get_webcam_device_data (CheeseWebcamDevice *webcam_device)
   i = 0;
   while (!pipeline_works && (i < G_N_ELEMENTS (GSTREAMER_VIDEO_SOURCES)))
   {
-    /* NOTE queue-size=2 can be removed as soon as gst-plugins-good 0.10.7 comes out */
-    if (strcmp (GSTREAMER_VIDEO_SOURCES[i], "v4l2src") == 0)
-    {
-      pipeline_desc = g_strdup_printf ("%s name=source device=%s queue-size=2 ! fakesink", 
-                                       GSTREAMER_VIDEO_SOURCES[i],
-                                       webcam_device->video_device);
-    }
-    else
-    {
-      pipeline_desc = g_strdup_printf ("%s name=source device=%s ! fakesink", 
-                                       GSTREAMER_VIDEO_SOURCES[i],
-                                       webcam_device->video_device);
-    }
+    pipeline_desc = g_strdup_printf ("%s name=source device=%s ! fakesink", 
+                                     GSTREAMER_VIDEO_SOURCES[i],
+                                     webcam_device->video_device);
     err = NULL;
     pipeline = gst_parse_launch (pipeline_desc, &err);
     if ((pipeline != NULL) && (err == NULL))
@@ -620,29 +610,14 @@ cheese_webcam_create_webcam_source_bin (CheeseWebcam *webcam)
       }
     }
 
-    /* NOTE queue-size=2 can be removed as soon as gst-plugins-good 0.10.7 comes out */
-    if (strcmp (selected_webcam->gstreamer_src, "v4l2src") == 0)
-    {
-      webcam_input = g_strdup_printf ("%s name=video_source device=%s queue-size=2 ! %s,width=%d,height=%d,framerate=%d/%d ! identity",
-                                      selected_webcam->gstreamer_src,
-                                      selected_webcam->video_device,
-                                      format->mimetype,
-                                      format->width,
-                                      format->height,
-                                      framerate_numerator,
-                                      framerate_denominator);
-    }
-    else
-    {
-      webcam_input = g_strdup_printf ("%s name=video_source device=%s ! %s,width=%d,height=%d,framerate=%d/%d ! identity",
-                                      selected_webcam->gstreamer_src,
-                                      selected_webcam->video_device,
-                                      format->mimetype,
-                                      format->width,
-                                      format->height,
-                                      framerate_numerator,
-                                      framerate_denominator);
-    }
+    webcam_input = g_strdup_printf ("%s name=video_source device=%s ! %s,width=%d,height=%d,framerate=%d/%d ! identity",
+                                    selected_webcam->gstreamer_src,
+                                    selected_webcam->video_device,
+                                    format->mimetype,
+                                    format->width,
+                                    format->height,
+                                    framerate_numerator,
+                                    framerate_denominator);
     g_print ("%s\n", webcam_input);
 
     priv->webcam_source_bin = gst_parse_bin_from_description (webcam_input,
@@ -934,6 +909,7 @@ cheese_webcam_set_effect (CheeseWebcam *webcam, CheeseWebcamEffect effect)
   effect_filter = gst_parse_bin_from_description (effects_pipeline_desc, TRUE, &err);
   if (!effect_filter || (err != NULL))
   {
+    g_error_free(err);
     g_error ("ERROR effect_filter\n");
   }
   cheese_webcam_change_effect_filter (webcam, effect_filter);
@@ -1136,7 +1112,9 @@ cheese_webcam_init (CheeseWebcam *webcam)
   if (!ok)
     g_error ("Unable link pipeline for photo");
 
+  gdk_threads_enter();
   XF86VidModeGetGamma (GDK_DISPLAY (), 0, &(priv->normal_gamma));
+  gdk_threads_leave();
 }
 
 CheeseWebcam*
